@@ -1,5 +1,5 @@
 from typing import Dict
-from bergen.queries.initiation import HOST_GQL
+from bergen.schemas.arkitekt.mutations.host import HOST_GQL
 from bergen.schema import DataModel
 from bergen.enums import ClientType, DataPointType
 from bergen.clients.default import Bergen
@@ -7,7 +7,7 @@ from bergen.clients.default import Bergen
 
 class PointBergen(Bergen):
 
-    def __init__(self, *args, point_inward=None, point_outward=None, point_port=8000, point_type = DataPointType.GRAPHQL, scopes= [], needs_negotiation=False, **kwargs) -> None:
+    def __init__(self, *args, point_inward=None, point_outward=None, point_port=None, point_type = DataPointType.GRAPHQL, scopes= [], needs_negotiation=False, **kwargs) -> None:
         super().__init__(*args, client_type = ClientType.POINT, scopes=scopes + ["host","provide"], **kwargs)
         self.model_registry: Dict[str, DataModel] = {}
         self.negotiate_additionals = {
