@@ -1,3 +1,4 @@
+from ..exception import ExceptionDataModel
 from pydantic.main import BaseModel
 from ....messages.types import  PROVIDE, PROVIDE_CRITICAL, PROVIDE_DONE, UNPROVIDE_CRITICAL
 from ....messages.base import MessageDataModel, MessageMetaExtensionsModel, MessageMetaModel, MessageModel
@@ -13,9 +14,7 @@ class MetaModel(MessageMetaModel):
     type: str = UNPROVIDE_CRITICAL
     extensions: Optional[MetaExtensionsModel]
 
-class DataModel(MessageDataModel):
-    message: Optional[str] #TODO: Maybe not optional
 
 class UnprovideCriticalMessage(MessageModel):
-    data: DataModel
+    data: ExceptionDataModel
     meta: MetaModel
\ No newline at end of file
