@@ -31,10 +31,9 @@ class ProtocolException(Exception):
 class BasePostman(Hookable):
     """ A Postman takes node requests and translates them to Bergen calls, basic implementations are GRAPHQL and PIKA"""
     
-    def __init__(self, requires_configuration=True, loop=None, client=None, **kwargs) -> None:
+    def __init__(self, client, requires_configuration=True, loop=None,**kwargs) -> None:
         super().__init__(**kwargs)
-        assert loop is not None, "Please provide a Loop to your Postman, Did you forget to call super.init with **kwargs?"
-        self.loop = loop or asyncio.get_event_loop()
+        self.loop = loop or client.loop or asyncio.get_event_loop()
         self.client = client
 
         # Assignments and their Cancellations
