@@ -1,6 +1,7 @@
 
 
 from abc import ABC, abstractmethod
+from bergen.clients.base import BaseBergen
 
 from websockets.exceptions import ConnectionClosedError
 from bergen.messages import *
@@ -29,10 +30,10 @@ DEBUG = True
 class WebsocketProvider(BaseProvider):
     ''' Is a mixin for Our Bergen '''
 
-    def __init__(self, host= None, port= None, protocol=None, auto_reconnect=True, auth=None, **kwargs) -> None:
-        super().__init__(**kwargs)
-        self.websocket_host = host
-        self.websocket_port = port
+    def __init__(self, client: BaseBergen, host=None, port=None,  protocol=None, auth=None, auto_reconnect=True,**kwargs) -> None:
+        super().__init__(client, **kwargs)
+        self.websocket_host = host or client.config.host
+        self.websocket_port = port or client.config.port
         self.websocket_protocol = protocol
         self.token = auth["token"]
 
